//**************************************************************************************************
//*  FRIDA: fast reliable interactive data analysis
//*  (C) Joachim Wuttke 1990-, v2(C++) 2001-
//*  http://apps.jcns.fz-juelich.de/frida
//**************************************************************************************************

//! \file  plowin.cpp
//! \brief implement SPloWin, to administer plot windows

#include "plowin.hpp"
#include "dualplot.hpp"

SPloWin::~SPloWin()
{
    for ( auto* pw: Plots )
        delete pw;
}

//! Initialize default choice of plot windows.

void SPloWin::initialize()
{
    auto m = instance();
    m->Plots.push_back( new CPlot( m->nPlot(), false, false ) );
    m->Plots.push_back( new CPlot( m->nPlot(), true,  false ) );
    m->Plots.push_back( new CPlot( m->nPlot(), false, true ) );
    m->Plots.push_back( new CPlot( m->nPlot(), true,  true ) );
    m->iPlot = 0; // current plot window
}

//! Select default window.

void SPloWin::select( int i ) {
    if( i<nPlot() )
        iPlot = i;
    else if ( i==nPlot() ){
        iPlot = i;
        Plots.push_back( new CPlot( nPlot(), false, false ) );
    } else
        throw std::string("invalid graphic window number");
}

//! List available windows.

void SPloWin::display_list() const {
    for( int i=0; i<nPlot(); ++i )
        printf( " %c %1i %s\n", i==iPlot ? '*' : ' ', i, Plots[i]->info().c_str() );
}
