//**************************************************************************************************
//*  FRIDA: fast reliable interactive data analysis
//*  (C) Joachim Wuttke 2001-
//*  http://apps.jcns.fz-juelich.de/frida
//**************************************************************************************************

//! \file  singleton.hpp
//! \brief declares and implements the mixin interface ISingleton.

#ifndef ISINGLETON_H
#define ISINGLETON_H

namespace triv {

//! Mixin interface for singleton classes.

template<class T>
class ISingleton {
 private:
    ISingleton(ISingleton const&) = delete;  //! To prevent copying
    void operator=(ISingleton const&) = delete; //! To prevent copying
 protected:
    ~ISingleton() {};
    ISingleton() {}
    typedef T* T_Pointer;
 public:
    static T* instance() { static T* instance = new T(); return instance; }
};

} // namespace triv

#endif // ISINGLETON_H
